<?php

namespace ZetaNet;

use ZetaNet\Exception\ApiException;
use ZetaNet\Exception\NetworkException;

class Client {
    private string $apiKey;
    private string $baseUrl;
    private array $options;

    public function __construct(array $config) {
        $this->apiKey = $config['apiKey'] ?? '';
        $this->baseUrl = $config['baseUrl'] ?? 'https://zetanet-api.incontrol.network/api';
        $this->options = $config['options'] ?? [];
    }

    /**
     * Perform ISRA check
     */
    public function israCheck(array $params): array {
        return $this->request('isra-check', $params);
    }

    /**
     * Perform prequalification check
     */
    public function prequalification(array $params): array {
        return $this->request('prequalification', $params);
    }

    /**
     * Perform zipcode check
     */
    public function zipcodeCheck(array $params): array {
        return $this->request('zipcode-check', $params);
    }

    /**
     * Make API request
     */
    private function request(string $endpoint, array $params): array {
        $ch = curl_init();
        
        $url = rtrim($this->baseUrl, '/') . '/' . $endpoint;
        
        curl_setopt_array($ch, [
            CURLOPT_URL => $url,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_POST => true,
            CURLOPT_POSTFIELDS => json_encode($params),
            CURLOPT_HTTPHEADER => [
                'Content-Type: application/json',
                'X-API-Key: ' . $this->apiKey,
                'Accept: application/json'
            ],
            CURLOPT_TIMEOUT => 30,
            CURLOPT_SSL_VERIFYPEER => true
        ] + $this->options);

        $response = curl_exec($ch);
        $statusCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $error = curl_error($ch);
        
        curl_close($ch);

        if ($error) {
            throw new NetworkException('Network error: ' . $error);
        }

        $data = json_decode($response, true);
        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new ApiException('Invalid JSON response', 500);
        }

        if ($statusCode >= 400) {
            throw new ApiException(
                $data['error']['message'] ?? 'Unknown error',
                $data['error']['code'] ?? $statusCode
            );
        }

        return $data['data'] ?? $data;
    }
}
